#
# spec file for package perl-Perl-PrereqScanner
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Perl-PrereqScanner
Name:           perl-Perl-PrereqScanner
Version:        1.100
Release:        1.8
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Tool to scan your Perl code for its prerequisites
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Meta::Requirements) >= 2.124000
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(Getopt::Long::Descriptive)
BuildRequires:  perl(List::Util) >= 1.33
BuildRequires:  perl(Module::Path)
BuildRequires:  perl(Moo) >= 2.000000
BuildRequires:  perl(Moo::Role)
BuildRequires:  perl(PPI) >= 1.215
BuildRequires:  perl(PPI::Document)
BuildRequires:  perl(Params::Util)
BuildRequires:  perl(String::RewritePrefix) >= 0.005
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(Types::Standard)
BuildRequires:  perl(namespace::autoclean)
Requires:       perl(CPAN::Meta::Requirements) >= 2.124000
Requires:       perl(Getopt::Long::Descriptive)
Requires:       perl(List::Util) >= 1.33
Requires:       perl(Module::Path)
Requires:       perl(Moo) >= 2.000000
Requires:       perl(Moo::Role)
Requires:       perl(PPI) >= 1.215
Requires:       perl(Params::Util)
Requires:       perl(String::RewritePrefix) >= 0.005
Requires:       perl(Types::Standard)
Requires:       perl(namespace::autoclean)
%{perl_requires}

%description
The scanner will extract loosely your distribution prerequisites from your
files.

The extraction may not be perfect but tries to do its best. It will
currently find the following prereqs:

  * plain lines beginning with 'use' or 'require' in your perl modules and
scripts, including minimum perl version

  * regular inheritance declared with the 'base' and 'parent' pragmata

  * Moose inheritance declared with the 'extends' keyword

  * Moose roles included with the 'with' keyword

  * OO namespace aliasing using the 'aliased' module

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri Apr 28 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.100
  see /usr/share/doc/packages/perl-Perl-PrereqScanner/Changes
  1.100     2023-04-27 10:00:37+02:00 Europe/Paris
  - convert to Moo (thanks, Dan Book!)
* Mon Jan  2 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.025
  see /usr/share/doc/packages/perl-Perl-PrereqScanner/Changes
  1.025     2022-12-31 21:10:00-05:00 America/New_York
  - update author contact info
* Sun Jul  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.024
  see /usr/share/doc/packages/perl-Perl-PrereqScanner/Changes
  1.024     2021-07-03 13:28:30-04:00 America/New_York
  - switched from List::MoreUtils to List::Util (thanks, Karen
    Etheridge!)
  - update author contact info
  - add docs on perl version policy
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.023
  see /usr/share/doc/packages/perl-Perl-PrereqScanner/Changes
  1.023     2015-04-05 22:23:53-04:00 America/New_York
  - improve test reliability when path to perl has a space in it
  1.022     2014-12-23 21:11:27-05:00 America/New_York
  - do not crash when encountering arg-less "use aliased;"
  1.021     2014-11-06 21:08:49-05:00 America/New_York
  - instead of always trying to use lib, add a -I switch to scan-perl-prereqs
  - when finding files to scan, find files, not anything else
* Sat Jul 19 2014 chris@computersalat.de
- update to 1.020
  - update CPAN::Meta::Requirements version to match current formatting
- fix deps
  * Many thanks to DAGOLDEN for switching amount of digits in version !!
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.019
  - add a warning about PPI's unclear interpretation of strings
* Mon Nov 25 2013 coolo@suse.com
- updated to 1.018
  - make the scan-perl-prereqs program also scan .PL and .cgi files
  - also check for "Foo->VERSION(x)" after "require Foo"
  - doc improvements from David Steinbrunner and Karen Etheridge
  - eliminate testing of Carp for its prereqs, which *did* change from older
    5.8.8 installs
* Fri Jul 26 2013 coolo@suse.com
- updated to 1.016
  - new executable is bundled, scan-perl-prereqs, to take the plae of
    scan_prereqs;  it has cpanm-friendly output by default, but supports
  - -pretty and --by-file (thanks to John SJ Anderson for some of the work on
    this!)
  - add Superclass scanner for superclass.pm (thanks, David Golden!)
  - make scan_prereqs scan .t files (thanks, David Golden!)
  - add scan_module method (thanks, Neil Bowers!)
  - lib.pm is now indexed in 02packages; stop skipping it (thanks, Kevin
    Dawson!)
* Sun Jun  9 2013 coolo@suse.com
- updated to 1.015
  - document that "no Module" also works (thanks for the report, Toby Inkster)
  - require a more recent PPI for various bugfixes that broke tests
    (thanks for the report, Salve J. Nilsen)
  - make scan_prereqs scan directories recursively (thanks, Jakob Voss)
  - if PPI parsing fails, include PPI::Document->errstr in error message
    (Christopher J. Madsen)
  - fix "with (...)" where spaces occur between with and parenthesized list
    (thanks to celogeek for the failing test)
* Sat May 26 2012 frank.lichtenheld@sophos.com
- updated to 1.011
  * require CPAN::Meta::Requirements 2.120630 and fix tests to reflect
    its v-string normalizing behavior
* Thu Feb 23 2012 coolo@suse.com
- updated to 1.010
  - fix documentation bug (thanks to Marius Olsthoorn for the report)
  - add a test case to prove someone wrong on the internet
* Wed Feb 15 2012 coolo@suse.com
- updated to 1.009
  - switch from Version::Requirements to CPAN::Meta::Requirements
* Tue Nov  1 2011 pascal.bleser@opensuse.org
- update to 1.008:
  * fix rt#72062 - look for "require Module; Module->VERSION(min);"
- changes from 1.007:
  * new option --combine for scan_prereqs script
- changes from 1.006:
  * add the POE scanner for POE components
- changes from 1.005:
  * stop stripping "always core" prereqs like strict and warnings
  * add the Aliased scanner for aliased.pm
* Wed Jun  1 2011 coolo@novell.com
- updated to 1.004
  - avoid calling a method on undef (i.e., cope with PPI doing surprising
    things)
  - fix a bug that caused things like "within" and "trextends" to trigger
    the Moose scanner
  - fix rt#61608 - missing description in whatisentry for TestMore.pm
* Mon Jan 17 2011 coolo@novell.com
- initial package 1.001
  * created by cpanspec 1.78.03
